import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:npay_component/components/tab_bar_widget/tab_button.dart';

class NPTabBarController extends ValueNotifier<int> {
  /// Creates a controller for an control tab bar index.
  NPTabBarController({ int index })
      : super(index ?? 0);

}

class NPTabBar extends StatefulWidget {
  ///
  final List<String> titles;

  final List<Widget> tabView;


  final Function(int tabIndex) onPressed;


  final NPTabBarController tabController;

  final EdgeInsetsGeometry padding;

  final Color color;

  const NPTabBar(
      {Key key,
      @required this.titles,
      this.onPressed,
      this.padding = EdgeInsets.zero,
      this.color = Colors.white,
      @required this.tabController,
      @required this.tabView})
      : super(key: key);

  @override
  _NPTabBarState createState() => _NPTabBarState();
}

class _NPTabBarState extends State<NPTabBar> {
  @override
  Widget build(BuildContext context) {
    return ValueListenableBuilder(
      builder: (BuildContext context, value, Widget child) {
        return Container(
          color: widget.color,
          child: Column(
            children: [
              Padding(
                padding: widget.padding,
                child: Container(
                  height: 32,
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.all(Radius.circular(8.0)),
                    color: Color(0xFFF4F6FA),
                  ),
                  child: Row(
                    children: List.generate(widget.titles.length, (index) {
                      return Expanded(
                        child: TabButton(
                          selectedPage: widget.tabController.value,
                          pageNumber: index,
                          title: widget.titles[index],
                          onPressed: () {
                            widget.tabController.value = index;
                            if (widget.onPressed != null) widget.onPressed(index);
                          },
                        ),
                      );
                    }).toList(),
                  ),
                ),
              ),
              Expanded(
                  child: IndexedStack(
                children: widget.tabView,
                index: widget.tabController.value,
              ))
            ],
          ),
        );
      },
      valueListenable: widget.tabController,
    );
  }
}
